import { Injectable, Provider } from '@angular/core';
import {
  DB_MODEL_COLUMNS,
  ID_COLUMN,
  PageColumns,
} from 'src/app/core/base/page.columns';
import { TableColumn } from 'src/app/modules/shared/components/table/table.model';
import { User } from 'src/app/model/auth/user';
import { Group } from 'src/app/model/entities/group';

@Injectable()
export class UsersColumns extends PageColumns<User> {
  get(): TableColumn<User>[] {
    return [
      ID_COLUMN,
      {
        name: 'username',
        translationKey: 'user.username',
        type: 'text',
        value: (row: User) => row.username,
      },
      {
        name: 'email',
        translationKey: 'user.email',
        type: 'text',
        value: (row: User) => row.email,
      },
      {
        name: 'roles',
        translationKey: 'common.roles',
        type: 'text',
        filterable: true,
        value: (row: User) => row.roles.map(role => role.name).join(', '),
        width: '300px',
      },
      ...DB_MODEL_COLUMNS,
    ];
  }

  static provide(): Provider[] {
    return [
      {
        provide: PageColumns,
        useClass: UsersColumns,
      },
      UsersColumns,
    ];
  }
}
